@@ -178,9 +178,25 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateRoundedRectangleGeometry(ID2D
 static HRESULT STDMETHODCALLTYPE d2d_factory_CreateEllipseGeometry(ID2D1Factory2 *iface,
         const D2D1_ELLIPSE *ellipse, ID2D1EllipseGeometry **geometry)
 {
-    FIXME("iface %p, ellipse %p, geometry %p stub!\n", iface, ellipse, geometry);
+    struct d2d_geometry *object;
+    HRESULT hr;
 
-    return E_NOTIMPL;
+    TRACE("iface %p, ellipse %s, geometry %p.\n", iface, debug_d2d_ellipse(ellipse), geometry);
+
+    if (!(object = heap_alloc_zero(sizeof(*object))))
+        return E_OUTOFMEMORY;
+
+    if (FAILED(hr = d2d_ellipse_geometry_init(object, (ID2D1Factory *)iface, ellipse)))
+    {
+        WARN("Failed to initialize ellipse geometry, hr %#x.\n", hr);
+        heap_free(object);
+        return hr;
+    }
+
+    TRACE("Created ellipse geometry %p.\n", object);
+    *geometry = (ID2D1EllipseGeometry *)&object->ID2D1Geometry_iface;
+
+    return S_OK;
 }
 
 static HRESULT STDMETHODCALLTYPE d2d_factory_CreateGeometryGroup(ID2D1Factory2 *iface,
@@ -697,6 +713,28 @@ HRESULT WINAPI D2D1CreateDevice(IDXGIDevice *dxgi_device,
     return hr;
 }
 
+void WINAPI D2D1SinCos(float angle, float *s, float *c)
+{
+    TRACE("angle %.8e, s %p, c %p.\n", angle, s, c);
+
+    *s = sinf(angle);
+    *c = cosf(angle);
+}
+
+float WINAPI D2D1Tan(float angle)
+{
+    TRACE("angle %.8e.\n", angle);
+
+    return tanf(angle);
+}
+
+float WINAPI D2D1Vec3Length(float x, float y, float z)
+{
+    TRACE("x %.8e, y %.8e, z %.8e.\n", x, y, z);
+
+    return sqrtf(x * x + y * y + z * z);
+}
+
 static BOOL get_config_key_dword(HKEY default_key, HKEY application_key, const char *name, DWORD *value)
 {
     DWORD type, data, size;
