@@ -92,28 +92,31 @@ static HRESULT WINAPI qualifier_set_QueryInterface(
 static HRESULT create_qualifier_enum( const WCHAR *class, const WCHAR *member, const WCHAR *name,
                                       IEnumWbemClassObject **iter )
 {
-    static const WCHAR fmtW[] =
-        {'S','E','L','E','C','T',' ','*',' ','F','R','O','M',' ','_','_','Q','U','A','L',
-         'I','F','I','E','R','S',' ','W','H','E','R','E',' ','C','l','a','s','s','=',
-         '\'','%','s','\'',' ','A','N','D',' ','M','e','m','b','e','r','=','\'','%','s','\'',' ',
-         'A','N','D',' ','N','a','m','e','=','\'','%','s','\'',0};
-    static const WCHAR fmt2W[] =
-        {'S','E','L','E','C','T',' ','*',' ','F','R','O','M',' ','_','_','Q','U','A','L',
-         'I','F','I','E','R','S',' ','W','H','E','R','E',' ','C','l','a','s','s','=',
-         '\'','%','s','\'',' ','A','N','D',' ','M','e','m','b','e','r','=','\'','%','s','\'',0};
-    static const WCHAR noneW[] = {'_','_','N','O','N','E',0};
+    static const WCHAR fmtW[] = L"SELECT * FROM __QUALIFIERS WHERE Class='%s' AND Member='%s' AND Name='%s'";
+    static const WCHAR fmt2W[] = L"SELECT * FROM __QUALIFIERS WHERE Class='%s' AND Member='%s'";
+    static const WCHAR fmt3W[] = L"SELECT * FROM __QUALIFIERS WHERE Class='%s'";
     WCHAR *query;
     HRESULT hr;
     int len;
 
-    if (!member) member = noneW;
-    len = lstrlenW( class ) + lstrlenW( member );
-    if (name) len += lstrlenW( name ) + ARRAY_SIZE(fmtW);
-    else len += ARRAY_SIZE(fmt2W);
-
-    if (!(query = heap_alloc( len * sizeof(WCHAR) ))) return E_OUTOFMEMORY;
-    if (name) swprintf( query, len, fmtW, class, member, name );
-    else swprintf( query, len, fmt2W, class, member );
+    if (member && name)
+    {
+        len = lstrlenW( class ) + lstrlenW( member ) + lstrlenW( name ) + ARRAY_SIZE(fmtW);
+        if (!(query = heap_alloc( len * sizeof(WCHAR) ))) return E_OUTOFMEMORY;
+        swprintf( query, len, fmtW, class, member, name );
+    }
+    else if (member)
+    {
+        len = lstrlenW( class ) + lstrlenW( member ) + ARRAY_SIZE(fmt2W);
+        if (!(query = heap_alloc( len * sizeof(WCHAR) ))) return E_OUTOFMEMORY;
+        swprintf( query, len, fmt2W, class, member );
+    }
+    else
+    {
+        len = lstrlenW( class ) + ARRAY_SIZE(fmt3W);
+        if (!(query = heap_alloc( len * sizeof(WCHAR) ))) return E_OUTOFMEMORY;
+        swprintf( query, len, fmt3W, class );
+    }
 
     hr = exec_query( query, iter );
     heap_free( query );
@@ -123,11 +126,6 @@ static HRESULT create_qualifier_enum( const WCHAR *class, const WCHAR *member, c
 static HRESULT get_qualifier_value( const WCHAR *class, const WCHAR *member, const WCHAR *name,
                                     VARIANT *val, LONG *flavor )
 {
-    static const WCHAR qualifiersW[] = {'_','_','Q','U','A','L','I','F','I','E','R','S',0};
-    static const WCHAR intvalueW[] = {'I','n','t','e','g','e','r','V','a','l','u','e',0};
-    static const WCHAR strvalueW[] = {'S','t','r','i','n','g','V','a','l','u','e',0};
-    static const WCHAR flavorW[] = {'F','l','a','v','o','r',0};
-    static const WCHAR typeW[] = {'T','y','p','e',0};
     IEnumWbemClassObject *iter;
     IWbemClassObject *obj;
     VARIANT var;
@@ -136,25 +134,28 @@ static HRESULT get_qualifier_value( const WCHAR *class, const WCHAR *member, con
     hr = create_qualifier_enum( class, member, name, &iter );
     if (FAILED( hr )) return hr;
 
-    hr = create_class_object( qualifiersW, iter, 0, NULL, &obj );
+    hr = create_class_object( NULL, iter, 0, NULL, &obj );
     IEnumWbemClassObject_Release( iter );
     if (FAILED( hr )) return hr;
 
     if (flavor)
     {
-        hr = IWbemClassObject_Get( obj, flavorW, 0, &var, NULL, NULL );
+        hr = IWbemClassObject_Get( obj, L"Flavor", 0, &var, NULL, NULL );
         if (hr != S_OK) goto done;
         *flavor = V_I4( &var );
     }
-    hr = IWbemClassObject_Get( obj, typeW, 0, &var, NULL, NULL );
+    hr = IWbemClassObject_Get( obj, L"Type", 0, &var, NULL, NULL );
     if (hr != S_OK) goto done;
     switch (V_UI4( &var ))
     {
     case CIM_STRING:
-        hr = IWbemClassObject_Get( obj, strvalueW, 0, val, NULL, NULL );
+        hr = IWbemClassObject_Get( obj, L"StringValue", 0, val, NULL, NULL );
         break;
     case CIM_SINT32:
-        hr = IWbemClassObject_Get( obj, intvalueW, 0, val, NULL, NULL );
+        hr = IWbemClassObject_Get( obj, L"IntegerValue", 0, val, NULL, NULL );
+        break;
+    case CIM_BOOLEAN:
+        hr = IWbemClassObject_Get( obj, L"BoolValue", 0, val, NULL, NULL );
         break;
     default:
         ERR("unhandled type %u\n", V_UI4( &var ));
@@ -175,7 +176,12 @@ static HRESULT WINAPI qualifier_set_Get(
 {
     struct qualifier_set *set = impl_from_IWbemQualifierSet( iface );
 
-    FIXME("%p, %s, %08x, %p, %p\n", iface, debugstr_w(wszName), lFlags, pVal, plFlavor);
+    TRACE("%p, %s, %08x, %p, %p\n", iface, debugstr_w(wszName), lFlags, pVal, plFlavor);
+    if (lFlags)
+    {
+        FIXME("flags %08x not supported\n", lFlags);
+        return E_NOTIMPL;
+    }
     return get_qualifier_value( set->class, set->member, wszName, pVal, plFlavor );
 }
 
@@ -202,8 +208,28 @@ static HRESULT WINAPI qualifier_set_GetNames(
     LONG lFlags,
     SAFEARRAY **pNames )
 {
-    FIXME("%p, %08x, %p\n", iface, lFlags, pNames);
-    return E_NOTIMPL;
+    struct qualifier_set *set = impl_from_IWbemQualifierSet( iface );
+    IEnumWbemClassObject *iter;
+    IWbemClassObject *obj;
+    HRESULT hr;
+
+    TRACE("%p, %08x, %p\n", iface, lFlags, pNames);
+    if (lFlags)
+    {
+        FIXME("flags %08x not supported\n", lFlags);
+        return E_NOTIMPL;
+    }
+
+    hr = create_qualifier_enum( set->class, set->member, NULL, &iter );
+    if (FAILED( hr )) return hr;
+
+    hr = create_class_object( NULL, iter, 0, NULL, &obj );
+    IEnumWbemClassObject_Release( iter );
+    if (FAILED( hr )) return hr;
+
+    hr = IWbemClassObject_GetNames( obj, NULL, 0, NULL, pNames );
+    IWbemClassObject_Release( obj );
+    return hr;
 }
 
 static HRESULT WINAPI qualifier_set_BeginEnumeration(
